@@ -1,10 +1,8 @@
-context("colorblind")
-
 test_that("colorblind_pal works", {
   p <- colorblind_pal()
-  expect_is(p, "function")
+  expect_type(p, "closure")
   expect_hexcolor(p(4))
-  expect_is(attr(p, "max_n"), "integer")
+  expect_type(attr(p, "max_n"), "integer")
 })
 
 test_that("colorblind_pal raises warning with to large n", {
@@ -12,13 +10,13 @@ test_that("colorblind_pal raises warning with to large n", {
 })
 
 test_that("scale_colour_colorblind works", {
-  expect_is(scale_colour_colorblind(), "ScaleDiscrete")
+  expect_s3_class(scale_colour_colorblind(), "ScaleDiscrete")
 })
 
 test_that("scale_color_canva works", {
-  expect_eqNe(scale_color_colorblind(), scale_colour_colorblind())
+  expect_equal_scale(scale_color_colorblind(), scale_colour_colorblind())
 })
 
 test_that("scale_fill_colorblind works", {
-  expect_is(scale_fill_colorblind(), "ScaleDiscrete")
+  expect_s3_class(scale_fill_colorblind(), "ScaleDiscrete")
 })
