@@ -1,19 +1,17 @@
-context("excel")
-
 test_that("excel_clasic_pal works", {
   pal <- excel_pal()
   n <- 5L
   values <- pal(n)
-  expect_is(values, "character")
-  expect_eqNe(length(values), n)
+  expect_type(values, "character")
+  expect_equal(length(values), n)
 })
 
 test_that("excel_clasic_pal with line = TRUE works", {
   pal <- excel_pal(line = TRUE)
   n <- 5L
   values <- pal(n)
-  expect_is(values, "character")
-  expect_eqNe(length(values), n)
+  expect_type(values, "character")
+  expect_equal(length(values), n)
 })
 
 test_that("calc_shape_pal raises warning for large n", {
@@ -24,8 +22,8 @@ test_that("excel_new_pal works", {
   pal <- excel_new_pal()
   n <- 5L
   vals <- pal(n)
-  expect_is(vals, "character")
-  expect_eqNe(length(vals), n)
+  expect_type(vals, "character")
+  expect_equal(length(vals), n)
 })
 
 test_that("excel_new_pal raises error for bad n", {
@@ -33,7 +31,7 @@ test_that("excel_new_pal raises error for bad n", {
 })
 
 test_that("theme_excel works", {
-  expect_is(theme_excel(), "theme")
+  expect_s3_class(theme_excel(), "theme")
 })
 
 test_that("excel_new_pal raises error with bad theme name", {
@@ -41,22 +39,22 @@ test_that("excel_new_pal raises error with bad theme name", {
 })
 
 test_that("scale_fill_excel works", {
-  expect_is(scale_fill_excel(), "ScaleDiscrete")
+  expect_s3_class(scale_fill_excel(), "ScaleDiscrete")
 })
 
 test_that("scale_colour_excel works", {
-  expect_is(scale_colour_excel(), "ScaleDiscrete")
+  expect_s3_class(scale_colour_excel(), "ScaleDiscrete")
 })
 
 test_that("scale_colour_excel works", {
-  expect_is(scale_fill_excel_new(), "ScaleDiscrete")
+  expect_s3_class(scale_fill_excel_new(), "ScaleDiscrete")
 })
 
 test_that("scale_fill_excel works", {
-  expect_is(scale_colour_excel_new(), "ScaleDiscrete")
+  expect_s3_class(scale_colour_excel_new(), "ScaleDiscrete")
 })
 
 test_that("theme_excel with horizontal = FALSE works", {
   thm <- theme_excel(horizontal = FALSE)
-  expect_eqNe(thm$panel.grid.major.y, element_blank())
+  expect_equal(thm$panel.grid.major.y, element_blank())
 })
